@@ -19,53 +19,34 @@ def google_trends():
         print('ERR hot terms failed!', str(e))
         return None
 
-# if __name__ == '__main__':
-#     print(google_trends())
+STOCKTICKERS = os.path.join(os.path.dirname(__file__), 'stocks.csv')
 SOURCES = Sources
-
 REDDIT_COMMUNITIES = Sources.reddit_communities
 TWITTER_USERS = Sources.twitter_users
 
-GOOGLESOURCES = os.path.join(os.path.dirname(__file__), 'google_sources.txt')
-POPULARSOURCES = os.path.join(os.path.dirname(__file__), 'popular_sources.txt')
-RSSSOURCES = os.path.join(os.path.dirname(__file__), 'rss_sources.txt')
-STOCKTICKERS = os.path.join(os.path.dirname(__file__), 'stocks.csv')
-METAVERSESOURCES = os.path.join(os.path.dirname(__file__), 'metaverse_sources.txt')
+ALL = [a for a in os.scandir(os.path.dirname(__file__))]
 
-SEARCHTERMS = os.path.join(os.path.dirname(__file__), 'searchterms.txt')
+def get_all_files():
+    raw_items = os.scandir(os.path.dirname(__file__))
+    files = []
+    for item in raw_items:
+        item: os.DirEntry = item
+        if item.is_dir() or item.is_file():
+            files.append(item.name)
+    return files
 
-USERAGENTS = os.path.join(os.path.dirname(__file__), 'useragents.txt')
-
-STOPWORDS = os.path.join(os.path.dirname(__file__), 'stopwords.txt')
-
-class Resource:
-    GOOGLE_SOURCES = GOOGLESOURCES
-    POPULAR_SOURCES = POPULARSOURCES
-    RSS_SOURCES = RSSSOURCES
-    METAVERSE_SOURCES = METAVERSESOURCES
-    USER_AGENTS = USERAGENTS
-    STOP_WORDS = STOPWORDS
-    SEARCH_TERMS = SEARCHTERMS
-
-    @staticmethod
-    def get_all_sources():
-        test = Resource.__dict__.keys()
-        variables = []
-        for item in test:
-            if str(item).__contains__("_SOURCES"):
-                variables.append(item)
-        return variables
-
-    @staticmethod
-    def get_source(sourceTerm):
-        sources = Resource.get_all_sources()
-        for src in sources:
-            srcSmall = str(src).lower()
-            sourceTermSmall = str(sourceTerm).lower()
-            if srcSmall.__contains__(sourceTermSmall):
-                mainSource = getattr(Resource, src)
+def get_source(sourceTerm):
+    sources = get_all_files()
+    for src in sources:
+        srcSmall = str(src).lower()
+        sourceTermSmall = str(sourceTerm).lower()
+        if srcSmall.__contains__(sourceTermSmall):
+            mainSource = os.path.join(os.path.dirname(__file__), src)
+            if src.endswith("_sources.txt"):
                 source_list = get_resource(mainSource)
-                return source_list
+            else:
+                source_list = get_resource_not_url(mainSource)
+            return source_list
 
 def get_resource(resource):
     """Uses generator to return next useragent in saved file
@@ -86,26 +67,26 @@ def get_random(items):
     return items[selection]
 
 def get_google_sources():
-    return get_resource(Resource.GOOGLE_SOURCES)
+    return get_source("google")
 
 def get_popular_sources():
-    return get_resource(Resource.POPULAR_SOURCES)
+    return get_source("popular")
 
 def get_rss_sources():
-    return get_resource(Resource.RSS_SOURCES)
+    return get_source("rss")
 
 def get_metaverse_sources():
-    return get_resource(Resource.METAVERSE_SOURCES)
+    return get_source("metaverse")
 
 def get_search_terms():
-    return get_resource_not_url(SEARCHTERMS)
+    return get_source("google")
 
 def get_random_user_agent():
-    all = get_resource_not_url(Resource.USER_AGENTS)
+    all = get_source("useragents")
     return LIST.get_random(all, False)
 
 def get_stopwords():
-    return get_resource_not_url(STOPWORDS)
+    return get_source("stopwords")
 
 def get_random_metaverse_source():
     m_urls = get_metaverse_sources()
@@ -179,18 +160,10 @@ def get_company_names_from_csv():
         list_of_companies.append((one, new_name))
     return list(set(list_of_companies))
 
-# if __name__ == '__main__':
-#     test = read_stock_csv_to_dict()
-#     list_of_companies = build_list_of_companies(test)
-#     from Jarticle.jCompany import jCompany
-#     jc = jCompany.constructor_jcompany()
-#     jc.add_companies(list_of_companies)
-#     print(test)
-
 def to_tokens(text):
     """ ALTERNATIVE: Split a string into array of words. """
     try:
         text = re.sub(r'[^\w ]', '', text)  # strip special chars
         return [x.strip('.').lower() for x in text.split()]
     except TypeError:
-        return None
\ No newline at end of file
+        return None
